leaftools.scale_preprolated_leaf_duration
=========================================

.. autofunction:: abjad.tools.leaftools.scale_preprolated_leaf_duration.scale_preprolated_leaf_duration
   :noindex:
